================
ACDH XML PyUtils
================

.. image:: https://github.com/acdh-oeaw/acdh-xml-pyutils/workflows/Build/badge.svg
        :target: https://github.com/acdh-oeaw/xml-arche-pyutils/workflows/Build/badge.svg
        :alt: Github Workflow Build acdh-arche-pyutils Status

.. image:: https://github.com/acdh-oeaw/acdh-xml-pyutils/workflows/Test/badge.svg
        :target: https://github.com/acdh-oeaw/acdh-xml-pyutils/workflows/Test/badge.svg
        :alt: Github Workflow Tests Status

.. image:: https://img.shields.io/pypi/v/acdh-xml-pyutils.svg
        :target: https://pypi.python.org/pypi/acdh-xml-pyutils
        :alt: PyPI Status

.. image:: https://readthedocs.org/projects/acdh-xml-pyutils/badge/?version=latest
        :target: https://acdh-xml-pyutils.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://codecov.io/gh/acdh-oeaw/acdh-xml-pyutils/branch/master/graph/badge.svg?token=oYG6gr1eec
        :target: https://codecov.io/gh/acdh-oeaw/acdh-xml-pyutils
    

Utility functions to work with XML


* Free software: MIT
* Documentation: https://acdh-xml-pyutils.readthedocs.io.


Features
--------

* parse XML from files, strings or URLS
* print/save parsed files

see `tests/test_xml.py` for usage examples

Credits
-------

This package was created with cookietemple_ using Cookiecutter_.

.. _cookietemple: https://cookietemple.com
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
